@@ -12,10 +12,12 @@ class SQLLexer(Lexer):
         GROUP_BY, HAVING, ORDER_BY,
         STAR,
 
+        CREATE, VIEW,
+
         INNER_JOIN, OUTER_JOIN, CROSS_JOIN, LEFT_JOIN, RIGHT_JOIN, FULL_JOIN, ON,
 
-        # Symbols
-        COMMA, LPAREN, RPAREN,
+        # Special
+        COMMA, LPAREN, RPAREN, PARAMETER,
 
         # Operators
         PLUS, MINUS, DIVIDE, MODULO,
@@ -27,7 +29,7 @@ class SQLLexer(Lexer):
         CAST, ID, INTEGER, FLOAT, STRING, NULL, TRUE, FALSE }
     ignore = ' \t\n'
 
-    # Tokens
+    # Keywords
     ON = r'\bON\b'
     ASC = r'\bASC\b'
     DESC = r'\bDESC\b'
@@ -45,6 +47,9 @@ class SQLLexer(Lexer):
     ORDER_BY = r'\bORDER BY\b'
     STAR = r'\*'
 
+    CREATE = r'\bCREATE\b'
+    VIEW = r'\bVIEW\b'
+
     INNER_JOIN = r'\bINNER JOIN\b'
     OUTER_JOIN = r'\bOUTER JOIN\b'
     CROSS_JOIN = r'\bCROSS JOIN\b'
@@ -52,13 +57,13 @@ class SQLLexer(Lexer):
     RIGHT_JOIN = r'\bRIGHT JOIN\b'
     FULL_JOIN = r'\bFULL JOIN\b'
 
-
+    # Special
     COMMA = r','
     LPAREN = r'\('
     RPAREN = r'\)'
+    PARAMETER = r'\?'
 
     # Operators
-
     PLUS = r'\+'
     MINUS = r'-'
     DIVIDE = r'/'
